@@ -1,3 +1,5 @@
+from typing import Tuple
+
 from django.contrib import admin
 from django.contrib.admin import ModelAdmin
 from django_audit_fields import audit_fieldset_tuple
@@ -13,4 +15,4 @@ class ZplLabelTemplatesAdmin(ModelAdmin):
         audit_fieldset_tuple,
     )
 
-    search_fields = ["name"]
+    search_fields: Tuple[str, ...] = ("name",)
