@@ -1,6 +1,6 @@
-from django.conf import settings
 from django.urls import reverse
 from django.views.generic.base import TemplateView
+from edc_dashboard.utils import get_bootstrap_version
 from edc_dashboard.view_mixins import EdcViewMixin
 from edc_navbar import NavbarViewMixin
 
@@ -9,7 +9,7 @@ from ..view_mixins import EdcLabelViewMixin
 
 class HomeView(EdcViewMixin, NavbarViewMixin, EdcLabelViewMixin, TemplateView):
 
-    template_name = f"edc_label/bootstrap{settings.EDC_BOOTSTRAP}/home.html"
+    template_name = f"edc_label/bootstrap{get_bootstrap_version()}/home.html"
     navbar_name = "edc_label"
     navbar_selected_item = "label"
 
